.. _recipe_asr.setup.defects:

asr.setup.defects
=================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.defects`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setup.defects.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.defects

or as a python module

.. code-block:: console

   $ python -m asr.setup.defects

Detailed description
--------------------
Generate defective atomic structures.

Steps
-----


asr.setup.defects
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.defects.main
   